@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2016-2017,2019-2020,2022-2023 Aurimas Cernius
+ * Copyright (C) 2011-2014,2016-2017,2019-2020,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -60,7 +60,7 @@ namespace gnote {
   bool RemoteControl::AddTagToNote(const Glib::ustring& uri, const Glib::ustring& tag_name)
   {
     return m_manager.find_by_uri(uri, [this, &tag_name](NoteBase & note) {
-      auto tag = m_manager.tag_manager().get_or_create_tag(tag_name);
+      Tag &tag = m_manager.tag_manager().get_or_create_tag(tag_name);
       note.add_tag(tag);
     });
   }
@@ -152,12 +152,12 @@ namespace gnote {
 
   std::vector<Glib::ustring> RemoteControl::GetAllNotesWithTag(const Glib::ustring& tag_name)
   {
-    Tag::Ptr tag = m_manager.tag_manager().get_tag(tag_name);
-    if (!tag)
+    auto tag = m_manager.tag_manager().get_tag(tag_name);
+    if(!tag)
       return std::vector<Glib::ustring>();
 
     std::vector<Glib::ustring> tagged_note_uris;
-    auto notes = tag->get_notes();
+    auto notes = tag.value().get().get_notes();
     for(NoteBase *iter : notes) {
       tagged_note_uris.push_back(iter->uri());
     }
@@ -241,8 +241,8 @@ namespace gnote {
   {
     std::vector<Glib::ustring> tags;
     m_manager.find_by_uri(uri, [&tags](NoteBase & note) {
-      for(auto & tag : note.get_tags()) {
-        tags.push_back(tag->normalized_name());
+      for(Tag &tag : note.get_tags()) {
+        tags.push_back(tag.normalized_name());
       }
     });
     return tags;
@@ -282,7 +282,7 @@ bool RemoteControl::RemoveTagFromNote(const Glib::ustring& uri,
 {
   return m_manager.find_by_uri(uri, [this, &tag_name](NoteBase & note) {
     if(auto tag = m_manager.tag_manager().get_tag(tag_name)) {
-      note.remove_tag(tag);
+      note.remove_tag(*tag);
     }
   });
 }
