@@ -134,7 +134,12 @@ namespace gnote {
         cmdline.execute();
       }
       else if(!(cmdline.background() || cmdline.shell_search())) {
-        new_main_window().present();
+        if(cmdline.do_new_window()) {
+          new_main_window().present();
+        }
+        else {
+          get_main_window().present();
+        }
       }
     }
 
@@ -251,17 +256,23 @@ namespace gnote {
 
   void Gnote::on_show_about_action(const Glib::VariantBase&)
   {
-    std::vector<Glib::ustring> authors;
-    authors.push_back("Aurimas Černius <aurisc4@gmail.com>");
-    authors.push_back("Debarshi Ray <debarshir@src.gnome.org>");
-    authors.push_back("Hubert Figuiere <hub@figuiere.net>");
-    authors.push_back("Iain Nicol <iainn@src.gnome.org>");
-    authors.push_back("Kevin Joly <kevin.joly@posteo.net>");
-    authors.push_back(_("and Tomboy original authors."));
+    std::vector<Glib::ustring> authors = {
+      "Aurimas Černius <aurimas.cernius@mailo.com>",
+      "Debarshi Ray <debarshir@src.gnome.org>",
+      "Hubert Figuiere <hub@figuiere.net>",
+      _("and Tomboy original authors."),
+    };
+
+    std::vector<Glib::ustring> contributors = {
+      "Iain Nicol <iainn@src.gnome.org>",
+      "Kevin Joly <kevin.joly@posteo.net>",
+      "Balló György <ballogyor@gmail.com>",
+    };
     
-    std::vector<Glib::ustring> documenters;
-    documenters.push_back("Pierre-Yves Luyten <py@luyten.fr>");
-    documenters.push_back("Aurimas Černius <aurisc4@gmail.com>");
+    std::vector<Glib::ustring> documenters = {
+      "Pierre-Yves Luyten <py@luyten.fr>",
+      "Aurimas Černius <aurimas.cernius@mailo.com>",
+    };
 
     Glib::ustring translators(_("translator-credits"));
     if (translators == "translator-credits")
@@ -277,11 +288,15 @@ namespace gnote {
                            "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                            "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
     about->set_comments(_("A simple and easy to use desktop note-taking application."));
-    about->set_website("https://wiki.gnome.org/Apps/Gnote");
+    /* TRANSLATORS:
+     * The link to main wiki page in English. You can localize it in subdirectory for your locale and have this link point to it.
+    */
+    about->set_website(_("https://gitlab.gnome.org/GNOME/gnote/-/blob/master/wiki/main.md"));
     about->set_website_label(_("Homepage"));
     about->set_authors(authors);
     about->set_documenters(documenters);
     about->set_translator_credits(translators);
+    about->add_credit_section(_("Contributors"), contributors);
     MainWindow & recent_changes = get_main_window();
     if(recent_changes.get_visible()) {
       about->set_modal(true);
@@ -485,6 +500,7 @@ namespace gnote {
     , m_do_search(false)
     , m_show_version(false)
     , m_do_new_note(false)
+    , m_do_new_window(false)
     , m_open_note(NULL)
     , m_open_start_here(false)
     , m_highlight_search(NULL)
@@ -497,6 +513,7 @@ namespace gnote {
         { "search", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, (void*)GnoteCommandLine::parse_func, _("Open the search all notes window with the search text."), _("text") },
         { "version", 0, 0, G_OPTION_ARG_NONE, &m_show_version, _("Print version information."), NULL },
         { "new-note", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, (void*)GnoteCommandLine::parse_func, _("Create and display a new note, with a optional title."), _("title") },
+        { "new-window", 0, 0, G_OPTION_ARG_NONE, &m_do_new_window, _("Open a new window."), NULL },
         { "open-note", 0, 0, G_OPTION_ARG_STRING, &m_open_note, _("Display the existing note matching title."), _("title/url") },
         { "start-here", 0, 0, G_OPTION_ARG_NONE, &m_open_start_here, _("Display the 'Start Here' note."), NULL },
         { "highlight-search", 0, 0, G_OPTION_ARG_STRING, &m_highlight_search, _("Search and highlight text in the opened note."), _("text") },
