@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017 Aurimas Cernius
+ * Copyright (C) 2014,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #ifndef _TEST_SYNCCLIENT_HPP_
 #define _TEST_SYNCCLIENT_HPP_
 
-#include "base/macros.hpp"
 #include "synchronization/gnotesyncclient.hpp"
 
 
@@ -31,7 +30,7 @@ class SyncClient
   : public gnote::sync::GnoteSyncClient
 {
 public:
-  typedef shared_ptr<SyncClient> Ptr;
+  typedef std::shared_ptr<SyncClient> Ptr;
 
   SyncClient(gnote::NoteManagerBase & manager);
 
