@@ -25,13 +25,13 @@
 #endif
 
 #include <algorithm>
-#include <condition_variable>
 
 #include <glibmm/i18n.h>
 #include <glibmm/stringutils.h>
 #include <gtkmm/label.h>
 #include <gtkmm/urilauncher.h>
 
+#include "base/monitor.hpp"
 #include "sharp/xmlreader.hpp"
 #include "sharp/xmlwriter.hpp"
 #include "sharp/string.hpp"
@@ -226,26 +226,22 @@ namespace gnote {
 
     void main_context_call(const sigc::slot<void()> & slot)
     {
-      std::mutex mutex;
-      std::condition_variable cond;
-      bool executed = false;
+      CompletionMonitor cond;
       std::exception_ptr ex;
 
-      std::unique_lock<std::mutex> lock(mutex);
-      main_context_invoke([slot, &cond, &mutex, &executed, &ex]() {
-        std::unique_lock<std::mutex> lock(mutex);
-        try {
-          slot();
-        }
-        catch(...) {
-          ex = std::current_exception();
-        }
-        executed = true;
-        cond.notify_one();
-      });
-      while(!executed) {
-        cond.wait(lock);
+      {
+        CompletionMonitor::WaitLock lock(cond);
+        main_context_invoke([slot, &cond, &ex]() {
+          CompletionMonitor::NotifyLock lock(cond);
+          try {
+            slot();
+          }
+          catch(...) {
+            ex = std::current_exception();
+          }
+        });
       }
+
       if(ex) {
         std::rethrow_exception(ex);
       }
