@@ -1280,15 +1280,15 @@ namespace gnote {
   {
     // FIXME: Just for kicks, spit out the current tags
     DBG_OUT ("%s tags:", get_note().get_title().c_str());
-    for(const auto & tag : get_note().get_tags()) {
-      DBG_OUT ("\t%s", tag->name().c_str());
+    for(const Tag &tag : get_note().get_tags()) {
+      DBG_OUT ("\t%s", tag.name().c_str());
     }
   }
 
 #ifdef DEBUG
-  void NoteTagsWatcher::on_tag_added(const NoteBase& DBG(note), const Tag::Ptr& DBG(tag))
+  void NoteTagsWatcher::on_tag_added(const NoteBase& DBG(note), const Tag& DBG(tag))
   {
-    DBG_OUT ("Tag added to %s: %s", note.get_title().c_str(), tag->name().c_str());
+    DBG_OUT ("Tag added to %s: %s", note.get_title().c_str(), tag.name().c_str());
   }
 
 
@@ -1301,10 +1301,10 @@ namespace gnote {
 
   void NoteTagsWatcher::on_tag_removed(const NoteBase&, const Glib::ustring& tag_name)
   {
-    Tag::Ptr tag = manager().tag_manager().get_tag(tag_name);
-    DBG_OUT ("Watchers.OnTagRemoved popularity count: %d", tag ? tag->popularity() : 0);
-    if (tag && tag->popularity() == 0) {
-      manager().tag_manager().remove_tag(tag);
+    auto tag = manager().tag_manager().get_tag(tag_name);
+    DBG_OUT ("Watchers.OnTagRemoved popularity count: %d", tag ? tag.value().get().popularity() : 0);
+    if(tag && tag.value().get().popularity() == 0) {
+      manager().tag_manager().remove_tag(*tag);
     }
   }
 
